pub struct ExtractedSignature {
pub signature_pem: String,
pub signed_payload: String,
}Expand description
Extracted SSH signature and signed payload from a git commit object.
Fields
signature_pem: StringThe SSH signature PEM block.
signed_payload: StringThe commit content with the gpgsig header removed (the signed payload).