#[non_exhaustive]pub enum EvidencePackError {
Canonicalize(String),
Decode(String),
OfflineVerification(String),
}Expand description
A typed failure parsing or verifying a compliance evidence pack.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Canonicalize(String)
Canonical serialization (json-canon) failed.
Decode(String)
The pack (or a JSON input) could not be decoded.
OfflineVerification(String)
Offline pack verification failed (tampered KEL, unpinned root, or a transparency proof that did not check out).