KeriIcpEvent

Struct KeriIcpEvent 

pub struct KeriIcpEvent {
    pub v: VersionString,
    pub d: Said,
    pub i: Prefix,
    pub s: KeriSequence,
    pub kt: Threshold,
    pub k: Vec<CesrKey>,
    pub nt: Threshold,
    pub n: Vec<Said>,
    pub bt: Threshold,
    pub b: Vec<Prefix>,
    pub c: Vec<ConfigTrait>,
    pub a: Vec<Seal>,
}
Inception event — creates a new KERI identity.

The inception event establishes the identifier prefix and commits to the first rotation key via the n (next) field.

Spec field order: [v, t, d, i, s, kt, k, nt, n, bt, b, c, a]

Fields

v: VersionString

Version string

d: Said

SAID (Self-Addressing Identifier) — Blake3 hash of event

i: Prefix

Identifier prefix (same as d for self-addressing inception)

s: KeriSequence

Sequence number (always 0 for inception)

kt: Threshold

Key signing threshold (hex integer or fractional weight list)

k: Vec<CesrKey>

Current public key(s), CESR-encoded

nt: Threshold

Next key signing threshold

n: Vec<Said>

Next key commitment(s) — Blake3 digests of next public key(s)

bt: Threshold

Witness/backer threshold

b: Vec<Prefix>

Witness/backer list (ordered AIDs)

c: Vec<ConfigTrait>

Configuration traits (e.g., EstablishmentOnly, DoNotDelegate)

a: Vec<Seal>

Anchored seals

Implementations

Source

impl IcpEvent

pub fn new(init: IcpEventInit) -> IcpEvent

Construct an IcpEvent from its required fields.