pub struct Ed25519Signature(/* private fields */);Expand description
A validated Ed25519 signature (64 bytes).
Implementations
Sourceimpl Ed25519Signature
impl Ed25519Signature
Sourcepub fn from_bytes(bytes: [u8; 64]) -> Self
pub fn from_bytes(bytes: [u8; 64]) -> Self
Creates a signature from a 64-byte array.
Sourcepub fn try_from_slice(slice: &[u8]) -> Result<Self, SignatureLengthError>
pub fn try_from_slice(slice: &[u8]) -> Result<Self, SignatureLengthError>
Attempts to create a signature from a byte slice, returning an error if the length is not 64.