pub struct VerifiedAttestation(/* private fields */);Expand description
An attestation that has passed signature verification.
This type enforces at compile time that an attestation’s signatures were verified before it can be stored. It can only be constructed by:
- Verification functions (
verify_with_keys,verify_with_capability) - The
dangerous_from_uncheckedescape hatch (for self-signed attestations)
Does NOT implement Deserialize to prevent bypassing verification by
deserializing directly.
Implementations
Sourceimpl VerifiedAttestation
impl VerifiedAttestation
Sourcepub fn inner(&self) -> &Attestation
pub fn inner(&self) -> &Attestation
Access the inner attestation.
Sourcepub fn into_inner(self) -> Attestation
pub fn into_inner(self) -> Attestation
Consume and return the inner attestation.
Methods from Deref<Target = Attestation>
Sourcepub fn is_revoked(&self) -> bool
pub fn is_revoked(&self) -> bool
Returns true if this attestation has been revoked.
Sourcepub fn to_debug_string(&self) -> String
pub fn to_debug_string(&self) -> String
Formats the attestation contents for debug or inspection purposes.