pub struct KeriIcpEvent {
pub v: VersionString,
pub d: Said,
pub i: Prefix,
pub s: KeriSequence,
pub kt: Threshold,
pub k: Vec<CesrKey>,
pub nt: Threshold,
pub n: Vec<Said>,
pub bt: Threshold,
pub b: Vec<Prefix>,
pub c: Vec<ConfigTrait>,
pub a: Vec<Seal>,
}Expand description
Inception event — creates a new KERI identity.
The inception event establishes the identifier prefix and commits
to the first rotation key via the n (next) field.
Spec field order: [v, t, d, i, s, kt, k, nt, n, bt, b, c, a]
Fields
v: VersionStringVersion string
d: SaidSAID (Self-Addressing Identifier) — Blake3 hash of event
i: PrefixIdentifier prefix (same as d for self-addressing inception)
s: KeriSequenceSequence number (always 0 for inception)
kt: ThresholdKey signing threshold (hex integer or fractional weight list)
k: Vec<CesrKey>Current public key(s), CESR-encoded
nt: ThresholdNext key signing threshold
n: Vec<Said>Next key commitment(s) — Blake3 digests of next public key(s)
bt: ThresholdWitness/backer threshold
b: Vec<Prefix>Witness/backer list (ordered AIDs)
c: Vec<ConfigTrait>Configuration traits (e.g., EstablishmentOnly, DoNotDelegate)
a: Vec<Seal>Anchored seals
Implementations